@@ -82,6 +82,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_events
@@ -144,6 +146,10 @@ class Certbot(
         :param sns_topic: The SNS topic to notify when a new cert is issued. If no topic is given one will be created automatically.
         :param timeout: The timeout duration for Lambda function. Default: cdk.Duraction.seconds(180)
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Certbot.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CertbotProps(
             hosted_zone_names=hosted_zone_names,
             letsencrypt_domains=letsencrypt_domains,
@@ -168,7 +174,7 @@ class Certbot(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="handler")
     def handler(self) -> aws_cdk.aws_lambda.Function:
         return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "handler"))
@@ -244,6 +250,27 @@ class CertbotProps:
         :param sns_topic: The SNS topic to notify when a new cert is issued. If no topic is given one will be created automatically.
         :param timeout: The timeout duration for Lambda function. Default: cdk.Duraction.seconds(180)
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CertbotProps.__init__)
+            check_type(argname="argument hosted_zone_names", value=hosted_zone_names, expected_type=type_hints["hosted_zone_names"])
+            check_type(argname="argument letsencrypt_domains", value=letsencrypt_domains, expected_type=type_hints["letsencrypt_domains"])
+            check_type(argname="argument letsencrypt_email", value=letsencrypt_email, expected_type=type_hints["letsencrypt_email"])
+            check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+            check_type(argname="argument enable_insights", value=enable_insights, expected_type=type_hints["enable_insights"])
+            check_type(argname="argument enable_object_deletion", value=enable_object_deletion, expected_type=type_hints["enable_object_deletion"])
+            check_type(argname="argument function_description", value=function_description, expected_type=type_hints["function_description"])
+            check_type(argname="argument function_name", value=function_name, expected_type=type_hints["function_name"])
+            check_type(argname="argument insights_arn", value=insights_arn, expected_type=type_hints["insights_arn"])
+            check_type(argname="argument layers", value=layers, expected_type=type_hints["layers"])
+            check_type(argname="argument object_prefix", value=object_prefix, expected_type=type_hints["object_prefix"])
+            check_type(argname="argument preferred_chain", value=preferred_chain, expected_type=type_hints["preferred_chain"])
+            check_type(argname="argument re_issue_days", value=re_issue_days, expected_type=type_hints["re_issue_days"])
+            check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
+            check_type(argname="argument run_on_deploy", value=run_on_deploy, expected_type=type_hints["run_on_deploy"])
+            check_type(argname="argument run_on_deploy_wait_minutes", value=run_on_deploy_wait_minutes, expected_type=type_hints["run_on_deploy_wait_minutes"])
+            check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
+            check_type(argname="argument sns_topic", value=sns_topic, expected_type=type_hints["sns_topic"])
+            check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
         self._values: typing.Dict[str, typing.Any] = {
             "hosted_zone_names": hosted_zone_names,
             "letsencrypt_domains": letsencrypt_domains,
